
## **hammad-dev** - *A collection of fun things I've made*

### **zyx** - *Super Duper Lightweight AI functions, built on LiteLLM & Instructor*

**Install**
```bash
pip install zyx
```

[**Examples**](./python/notebooks/zyx/getting-started.ipynb)